4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
|
# File 'lib/hieracles/help.rb', line 4
def self.usage
return <<-END
Usage: hc <fqdn> <command> [extra_args]
Available commands:
info provides the farm, datacenter, country
associated to the given fqdn
files list all files containing params affecting this fqdn
(in more than commons)
paths list all file paths for files with params
modules list modules included in the farm where the node is
params list params for the node matching the fqdn
An extra filter string can be added to limit the list
use ruby regexp without the enclosing slashes
eg. hc <fqdn> params postfix.*version
eg. hc <fqdn> params '^postfix'
eg. hc <fqdn> params 'version$'
allparams same as params but including the common.yaml params (huge)
Also accepts a search string
Extra args:
-f <plain|console|csv|yaml|rawyaml> default console
-p extraparam=what;anotherparam=this
-c <configfile>
-h <hierafile>
-b <basepath> default ./
-e <encdir>
-y <fact_file> - facts in yaml format
-j <fact_file> - facts in json format
-v just displays the version of Hieracles
END
end
|