Module: Hieracles::Help

Defined in:
lib/hieracles/help.rb

Class Method Summary collapse

Class Method Details

.usageObject



4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
# File 'lib/hieracles/help.rb', line 4

def self.usage
  return "\n  Usage: hc <fqdn> <command> [extra_args]\n\n  Available commands:\n    info        provides the farm, datacenter, country\n                associated to the given fqdn\n    files       list all files containing params affecting this fqdn\n                (in more than commons)\n    paths       list all file paths for files with params\n    modules     list modules included in the farm where the node is\n    params      list params for the node matching the fqdn\n                An extra filter string can be added to limit the list\n                use ruby regexp without the enclosing slashes\n                eg. hc <fqdn> params postfix.*version\n                eg. hc <fqdn> params '^postfix'\n                eg. hc <fqdn> params 'version$'\n    allparams   same as params but including the common.yaml params (huge)\n                Also accepts a search string\n\n  Extra args:\n    -f <plain|console|csv|yaml|rawyaml> default console\n    -p extraparam=what;anotherparam=this \n    -c <configfile>\n    -h <hierafile>\n    -b <basepath> default ./\n    -e <encdir>\n    -y <fact_file> - facts in yaml format\n    -j <fact_file> - facts in json format\n    -v just displays the version of Hieracles\n  END\nend\n"